==> anwiba-commons-thread-1.1.121-sources.jar: net/anwiba/commons/thread/queue/IQueueNameConstans.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.thread.queue;

public interface IQueueNameConstans {

  public static final String CONTENT_MANAGMENT_QUEUE = "CONTENT_MANAGMENT_QUEUE"; //$NON-NLS-1$
  public static final String CONTENT_IO_QUEUE = "CONTENT_IO_QUEUE"; //$NON-NLS-1$
  public static final String METADATA_IO_QUEUE = "METADATA_IO_QUEUE"; //$NON-NLS-1$
  public static final String MAP_VIEW_RENDRER = "MAP_VIEW_RENDRER"; //$NON-NLS-1$
  public static final String SCRIPTING_QUEUE = "SCRIPTING_QUEUE"; //$NON-NLS-1$
  public static final String CANCEL_QUEUE = "CANCEL_QUEUE"; //$NON-NLS-1$
  public static final String IMAGE_CACHE_WRITER_QUEUE = "CACHE_WRITER_QUEUE"; //$NON-NLS-1$
  public static final String AUDIT_LOGGING_QUEUE = "AUDIT_LOGGING_QUEUE"; //$NON-NLS-1$
  public static final String CONTENT_TIMER_QUEUE = "CONTENT_RELOAD_QUEUE"; //$NON-NLS-1$

}

==> anwiba-commons-thread-1.1.158-sources.jar: net/anwiba/commons/thread/queue/IQueueNameConstans.java <==
/*
 * #%L
 * anwiba commons advanced
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.thread.queue;

public interface IQueueNameConstans {

  public static final String CONTENT_MANAGMENT_QUEUE = "CONTENT_MANAGMENT_QUEUE"; //$NON-NLS-1$
  public static final String CONTENT_IO_QUEUE = "CONTENT_IO_QUEUE"; //$NON-NLS-1$
  public static final String METADATA_IO_QUEUE = "METADATA_IO_QUEUE"; //$NON-NLS-1$
  public static final String MAP_VIEW_RENDRER = "MAP_VIEW_RENDRER"; //$NON-NLS-1$
  public static final String SCRIPTING_QUEUE = "SCRIPTING_QUEUE"; //$NON-NLS-1$
  public static final String CANCEL_QUEUE = "CANCEL_QUEUE"; //$NON-NLS-1$
  public static final String CACHE_WRITER_QUEUE = "CACHE_WRITER_QUEUE"; //$NON-NLS-1$
  public static final String AUDIT_LOGGING_QUEUE = "AUDIT_LOGGING_QUEUE"; //$NON-NLS-1$
  public static final String CONTENT_TIMER_QUEUE = "CONTENT_RELOAD_QUEUE"; //$NON-NLS-1$

}
